@@ -170,6 +170,18 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._update(_profile.Profile, profile, **attrs)
 
+    def validate_profile(self, **attrs):
+        """Validate a profile spec.
+
+        :param dict attrs: Keyword arguments that will be used to create a
+             :class:`~openstack.cluster.v1.profile.ProfileValidate`, it is
+             comprised of the properties on the Profile class.
+
+        :returns: The results of profile validation.
+        :rtype: :class:`~openstack.cluster.v1.profile.ProfileValidate`.
+        """
+        return self._create(_profile.ProfileValidate, **attrs)
+
     def create_cluster(self, **attrs):
         """Create a new cluster from attributes.
 
@@ -291,6 +303,20 @@ class Proxy(proxy2.BaseProxy):
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
         return obj.del_nodes(self.session, nodes)
 
+    def cluster_replace_nodes(self, cluster, nodes):
+        """Replace the nodes in a cluster with specified nodes.
+
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param nodes: List of nodes to be deleted/added to the cluster.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        if isinstance(cluster, _cluster.Cluster):
+            obj = cluster
+        else:
+            obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
+        return obj.replace_nodes(self.session, nodes)
+
     def cluster_scale_out(self, cluster, count=None):
         """Inflate the size of a cluster.
 
@@ -629,6 +655,18 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._update(_policy.Policy, policy, **attrs)
 
+    def validate_policy(self, **attrs):
+        """Validate a policy spec.
+
+        :param dict attrs: Keyword arguments that will be used to create a
+             :class:`~openstack.cluster.v1.policy.PolicyValidate`, it is
+             comprised of the properties on the Policy class.
+
+        :returns: The results of Policy validation.
+        :rtype: :class:`~openstack.cluster.v1.policy.PolicyValidate`.
+        """
+        return self._create(_policy.PolicyValidate, **attrs)
+
     def cluster_policies(self, cluster, **query):
         """Retrieve a generator of cluster-policy bindings.
 
