@@ -16,8 +16,10 @@ import uuid
 from openstack.network.v2 import _proxy
 from openstack.network.v2 import address_scope
 from openstack.network.v2 import agent
+from openstack.network.v2 import auto_allocated_topology
 from openstack.network.v2 import availability_zone
 from openstack.network.v2 import extension
+from openstack.network.v2 import flavor
 from openstack.network.v2 import floating_ip
 from openstack.network.v2 import health_monitor
 from openstack.network.v2 import listener
@@ -40,17 +42,22 @@ from openstack.network.v2 import router
 from openstack.network.v2 import security_group
 from openstack.network.v2 import security_group_rule
 from openstack.network.v2 import segment
+from openstack.network.v2 import service_profile
+from openstack.network.v2 import service_provider
 from openstack.network.v2 import subnet
 from openstack.network.v2 import subnet_pool
 from openstack.network.v2 import vpn_service
-from openstack.tests.unit import test_proxy_base
+from openstack import proxy2 as proxy_base2
+from openstack.tests.unit import test_proxy_base2
 
 
 QOS_POLICY_ID = 'qos-policy-id-' + uuid.uuid4().hex
 QOS_RULE_ID = 'qos-rule-id-' + uuid.uuid4().hex
+NETWORK_ID = 'network-id-' + uuid.uuid4().hex
+AGENT_ID = 'agent-id-' + uuid.uuid4().hex
 
 
-class TestNetworkProxy(test_proxy_base.TestProxyBase):
+class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def setUp(self):
         super(TestNetworkProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -104,6 +111,24 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
                                    availability_zone.AvailabilityZone,
                                    paginated=False)
 
+    def test_dhcp_agent_hosting_networks(self):
+        self.verify_list(
+            self.proxy.dhcp_agent_hosting_networks,
+            agent.DHCPAgentHostingNetwork,
+            paginated=False,
+            method_kwargs={'agent': AGENT_ID},
+            expected_kwargs={'agent_id': AGENT_ID}
+        )
+
+    def test_network_hosting_dhcp_agents(self):
+        self.verify_list(
+            self.proxy.network_hosting_dhcp_agents,
+            network.NetworkHostingDHCPAgent,
+            paginated=False,
+            method_kwargs={'network': NETWORK_ID},
+            expected_kwargs={'network_id': NETWORK_ID}
+        )
+
     def test_extension_find(self):
         self.verify_find(self.proxy.find_extension, extension.Extension)
 
@@ -297,6 +322,49 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_network_update(self):
         self.verify_update(self.proxy.update_network, network.Network)
 
+    def test_flavor_create_attrs(self):
+        self.verify_create(self.proxy.create_flavor, flavor.Flavor)
+
+    def test_flavor_delete(self):
+        self.verify_delete(self.proxy.delete_flavor, flavor.Flavor, True)
+
+    def test_flavor_find(self):
+        self.verify_find(self.proxy.find_flavor, flavor.Flavor)
+
+    def test_flavor_get(self):
+        self.verify_get(self.proxy.get_flavor, flavor.Flavor)
+
+    def test_flavor_update(self):
+        self.verify_update(self.proxy.update_flavor, flavor.Flavor)
+
+    def test_flavors(self):
+        self.verify_list(self.proxy.flavors, flavor.Flavor,
+                         paginated=True)
+
+    def test_service_profile_create_attrs(self):
+        self.verify_create(self.proxy.create_service_profile,
+                           service_profile.ServiceProfile)
+
+    def test_service_profile_delete(self):
+        self.verify_delete(self.proxy.delete_service_profile,
+                           service_profile.ServiceProfile, True)
+
+    def test_service_profile_find(self):
+        self.verify_find(self.proxy.find_service_profile,
+                         service_profile.ServiceProfile)
+
+    def test_service_profile_get(self):
+        self.verify_get(self.proxy.get_service_profile,
+                        service_profile.ServiceProfile)
+
+    def test_service_profiles(self):
+        self.verify_list(self.proxy.service_profiles,
+                         service_profile.ServiceProfile, paginated=True)
+
+    def test_service_profile_update(self):
+        self.verify_update(self.proxy.update_service_profile,
+                           service_profile.ServiceProfile)
+
     def test_network_ip_availability_find(self):
         self.verify_find(self.proxy.find_network_ip_availability,
                          network_ip_availability.NetworkIPAvailability)
@@ -313,8 +381,7 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
         self.verify_create(self.proxy.create_pool_member,
                            pool_member.PoolMember,
                            method_kwargs={"pool": "test_id"},
-                           expected_kwargs={"path_args": {
-                               "pool_id": "test_id"}})
+                           expected_kwargs={"pool_id": "test_id"})
 
     def test_pool_member_delete(self):
         self.verify_delete(self.proxy.delete_pool_member,
@@ -327,28 +394,31 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
                            {"pool": "test_id"}, {"pool_id": "test_id"})
 
     def test_pool_member_find(self):
-        self.verify_find(self.proxy.find_pool_member,
-                         pool_member.PoolMember,
-                         path_args={"pool_id": "test_id"})
+        self._verify2('openstack.proxy2.BaseProxy._find',
+                      self.proxy.find_pool_member,
+                      method_args=["MEMBER", "POOL"],
+                      expected_args=[pool_member.PoolMember, "MEMBER"],
+                      expected_kwargs={"pool_id": "POOL",
+                                       "ignore_missing": True})
 
     def test_pool_member_get(self):
-        self._verify2('openstack.proxy.BaseProxy._get',
+        self._verify2('openstack.proxy2.BaseProxy._get',
                       self.proxy.get_pool_member,
-                      method_args=["resource_or_id", "test_id"],
-                      expected_args=[pool_member.PoolMember,
-                                     "resource_or_id"],
-                      expected_kwargs={"path_args": {"pool_id": "test_id"}})
+                      method_args=["MEMBER", "POOL"],
+                      expected_args=[pool_member.PoolMember, "MEMBER"],
+                      expected_kwargs={"pool_id": "POOL"})
 
     def test_pool_members(self):
         self.verify_list(self.proxy.pool_members, pool_member.PoolMember,
                          paginated=False, method_args=["test_id"],
-                         expected_kwargs={"path_args": {
-                             "pool_id": "test_id"}})
+                         expected_kwargs={"pool_id": "test_id"})
 
     def test_pool_member_update(self):
-        self.verify_update(self.proxy.update_pool_member,
-                           pool_member.PoolMember,
-                           path_args={"pool_id": "test_id"})
+        self._verify2("openstack.proxy2.BaseProxy._update",
+                      self.proxy.update_pool_member,
+                      method_args=["MEMBER", "POOL"],
+                      expected_args=[pool_member.PoolMember, "MEMBER"],
+                      expected_kwargs={"pool_id": "POOL"})
 
     def test_pool_create_attrs(self):
         self.verify_create(self.proxy.create_pool, pool.Pool)
@@ -397,33 +467,39 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             self.proxy.create_qos_bandwidth_limit_rule,
             qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rule_delete(self):
         self.verify_delete(
             self.proxy.delete_qos_bandwidth_limit_rule,
             qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
             False, input_path_args=["resource_or_id", QOS_POLICY_ID],
-            expected_path_args={'qos_policy_id': QOS_POLICY_ID},)
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rule_delete_ignore(self):
         self.verify_delete(
             self.proxy.delete_qos_bandwidth_limit_rule,
             qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
             True, input_path_args=["resource_or_id", QOS_POLICY_ID],
-            expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rule_find(self):
-        self.verify_find(self.proxy.find_qos_bandwidth_limit_rule,
-                         qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
-                         path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._find',
+                      self.proxy.find_qos_bandwidth_limit_rule,
+                      method_args=['rule_id', policy],
+                      expected_args=[
+                          qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+                          'rule_id'],
+                      expected_kwargs={'ignore_missing': True,
+                                       'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rule_get(self):
         self.verify_get(
             self.proxy.get_qos_bandwidth_limit_rule,
             qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rules(self):
         self.verify_list(
@@ -431,20 +507,26 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
             paginated=False,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_bandwidth_limit_rule_update(self):
-        self.verify_update(
-            self.proxy.update_qos_bandwidth_limit_rule,
-            qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
-            path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._update',
+                      self.proxy.update_qos_bandwidth_limit_rule,
+                      method_args=['rule_id', policy],
+                      method_kwargs={'foo': 'bar'},
+                      expected_args=[
+                          qos_bandwidth_limit_rule.QoSBandwidthLimitRule,
+                          'rule_id'],
+                      expected_kwargs={'qos_policy_id': QOS_POLICY_ID,
+                                       'foo': 'bar'})
 
     def test_qos_dscp_marking_rule_create_attrs(self):
         self.verify_create(
             self.proxy.create_qos_dscp_marking_rule,
             qos_dscp_marking_rule.QoSDSCPMarkingRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_dscp_marking_rule_delete(self):
         self.verify_delete(
@@ -461,16 +543,21 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
 
     def test_qos_dscp_marking_rule_find(self):
-        self.verify_find(self.proxy.find_qos_dscp_marking_rule,
-                         qos_dscp_marking_rule.QoSDSCPMarkingRule,
-                         path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._find',
+                      self.proxy.find_qos_dscp_marking_rule,
+                      method_args=['rule_id', policy],
+                      expected_args=[qos_dscp_marking_rule.QoSDSCPMarkingRule,
+                                     'rule_id'],
+                      expected_kwargs={'ignore_missing': True,
+                                       'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_dscp_marking_rule_get(self):
         self.verify_get(
             self.proxy.get_qos_dscp_marking_rule,
             qos_dscp_marking_rule.QoSDSCPMarkingRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_dscp_marking_rules(self):
         self.verify_list(
@@ -478,20 +565,26 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             qos_dscp_marking_rule.QoSDSCPMarkingRule,
             paginated=False,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_dscp_marking_rule_update(self):
-        self.verify_update(
-            self.proxy.update_qos_dscp_marking_rule,
-            qos_dscp_marking_rule.QoSDSCPMarkingRule,
-            path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._update',
+                      self.proxy.update_qos_dscp_marking_rule,
+                      method_args=['rule_id', policy],
+                      method_kwargs={'foo': 'bar'},
+                      expected_args=[
+                          qos_dscp_marking_rule.QoSDSCPMarkingRule,
+                          'rule_id'],
+                      expected_kwargs={'qos_policy_id': QOS_POLICY_ID,
+                                       'foo': 'bar'})
 
     def test_qos_minimum_bandwidth_rule_create_attrs(self):
         self.verify_create(
             self.proxy.create_qos_minimum_bandwidth_rule,
             qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_minimum_bandwidth_rule_delete(self):
         self.verify_delete(
@@ -508,16 +601,22 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             expected_path_args={'qos_policy_id': QOS_POLICY_ID}, )
 
     def test_qos_minimum_bandwidth_rule_find(self):
-        self.verify_find(self.proxy.find_qos_minimum_bandwidth_rule,
-                         qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
-                         path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._find',
+                      self.proxy.find_qos_minimum_bandwidth_rule,
+                      method_args=['rule_id', policy],
+                      expected_args=[
+                          qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+                          'rule_id'],
+                      expected_kwargs={'ignore_missing': True,
+                                       'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_minimum_bandwidth_rule_get(self):
         self.verify_get(
             self.proxy.get_qos_minimum_bandwidth_rule,
             qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_minimum_bandwidth_rules(self):
         self.verify_list(
@@ -525,13 +624,19 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
             paginated=False,
             method_kwargs={'qos_policy': QOS_POLICY_ID},
-            expected_kwargs={'path_args': {'qos_policy_id': QOS_POLICY_ID}})
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID})
 
     def test_qos_minimum_bandwidth_rule_update(self):
-        self.verify_update(
-            self.proxy.update_qos_minimum_bandwidth_rule,
-            qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
-            path_args={'qos_policy_id': QOS_POLICY_ID})
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify2('openstack.proxy2.BaseProxy._update',
+                      self.proxy.update_qos_minimum_bandwidth_rule,
+                      method_args=['rule_id', policy],
+                      method_kwargs={'foo': 'bar'},
+                      expected_args=[
+                          qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule,
+                          'rule_id'],
+                      expected_kwargs={'qos_policy_id': QOS_POLICY_ID,
+                                       'foo': 'bar'})
 
     def test_qos_policy_create_attrs(self):
         self.verify_create(self.proxy.create_qos_policy, qos_policy.QoSPolicy)
@@ -570,12 +675,16 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_quota_get(self):
         self.verify_get(self.proxy.get_quota, quota.Quota)
 
-    def test_quota_default_get(self):
-        self.verify_get(self.proxy.get_quota_default, quota.QuotaDefault,
-                        value=[mock.sentinel.project_id],
-                        expected_args=[quota.QuotaDefault],
-                        expected_kwargs={"path_args": {
-                            "project": mock.sentinel.project_id}})
+    @mock.patch.object(proxy_base2.BaseProxy, "_get_resource")
+    def test_quota_default_get(self, mock_get):
+        fake_quota = mock.Mock(project_id='PROJECT')
+        mock_get.return_value = fake_quota
+        self._verify2("openstack.proxy2.BaseProxy._get",
+                      self.proxy.get_quota_default,
+                      method_args=['QUOTA_ID'],
+                      expected_args=[quota.QuotaDefault],
+                      expected_kwargs={'project': "PROJECT"})
+        mock_get.assert_called_once_with(quota.Quota, 'QUOTA_ID')
 
     def test_quotas(self):
         self.verify_list(self.proxy.quotas, quota.Quota, paginated=False)
@@ -822,3 +931,30 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def test_vpn_service_update(self):
         self.verify_update(self.proxy.update_vpn_service,
                            vpn_service.VPNService)
+
+    def test_service_provider(self):
+        self.verify_list(self.proxy.service_providers,
+                         service_provider.ServiceProvider,
+                         paginated=False)
+
+    def test_auto_allocated_topology_get(self):
+        self.verify_get(self.proxy.get_auto_allocated_topology,
+                        auto_allocated_topology.AutoAllocatedTopology)
+
+    def test_auto_allocated_topology_delete(self):
+        self.verify_delete(self.proxy.delete_auto_allocated_topology,
+                           auto_allocated_topology.AutoAllocatedTopology,
+                           False)
+
+    def test_auto_allocated_topology_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_auto_allocated_topology,
+                           auto_allocated_topology.AutoAllocatedTopology,
+                           True)
+
+    def test_validate_topology(self):
+        self.verify_get(self.proxy.validate_auto_allocated_topology,
+                        auto_allocated_topology.ValidateTopology,
+                        value=[mock.sentinel.project_id],
+                        expected_args=[
+                            auto_allocated_topology.ValidateTopology],
+                        expected_kwargs={"project": mock.sentinel.project_id})
