@@ -19,6 +19,8 @@ class TestProfile(base.TestCase):
     def test_init(self):
         prof = profile.Profile()
         expected = [
+            'alarming',
+            'baremetal',
             'clustering',
             'compute',
             'database',
@@ -36,6 +38,7 @@ class TestProfile(base.TestCase):
 
     def test_default_versions(self):
         prof = profile.Profile()
+        self.assertEqual('v1', prof.get_filter('baremetal').version)
         self.assertEqual('v1', prof.get_filter('clustering').version)
         self.assertEqual('v2', prof.get_filter('compute').version)
         self.assertEqual('v1', prof.get_filter('database').version)
@@ -45,16 +48,20 @@ class TestProfile(base.TestCase):
         self.assertEqual('v1', prof.get_filter('object-store').version)
         self.assertEqual('v1', prof.get_filter('orchestration').version)
         self.assertEqual('v1', prof.get_filter('key-manager').version)
-        self.assertEqual('v1', prof.get_filter('metering').version)
+        self.assertEqual('v2', prof.get_filter('metering').version)
         self.assertEqual('v2', prof.get_filter('volume').version)
         self.assertEqual('v1', prof.get_filter('messaging').version)
 
     def test_set(self):
         prof = profile.Profile()
-        prof.set_version('compute', 'v2')
-        self.assertEqual('v2', prof.get_filter('compute').version)
+        prof.set_version('alarming', 'v2')
+        self.assertEqual('v2', prof.get_filter('alarming').version)
+        prof.set_version('baremetal', 'v1')
+        self.assertEqual('v1', prof.get_filter('baremetal').version)
         prof.set_version('clustering', 'v1')
         self.assertEqual('v1', prof.get_filter('clustering').version)
+        prof.set_version('compute', 'v2')
+        self.assertEqual('v2', prof.get_filter('compute').version)
         prof.set_version('database', 'v3')
         self.assertEqual('v3', prof.get_filter('database').version)
         prof.set_version('identity', 'v4')
